pub struct BiVec<F, S> { /* private fields */ }Implementations
Sourceimpl<F, S> BiVec<F, S>
impl<F, S> BiVec<F, S>
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
Sourceimpl<F, S> BiVec<F, S>
impl<F, S> BiVec<F, S>
Sourcepub fn dedup_first_elements(&mut self)
pub fn dedup_first_elements(&mut self)
Unimplemented
Sourcepub fn dedup_second_elements(&mut self)
pub fn dedup_second_elements(&mut self)
Unimplemented
Sourceimpl<F, S> BiVec<F, S>
impl<F, S> BiVec<F, S>
Sourcepub fn splice(
&mut self,
range: impl RangeBounds<usize>,
replace_with: impl IntoIterator<Item = (F, S)>,
) -> !
pub fn splice( &mut self, range: impl RangeBounds<usize>, replace_with: impl IntoIterator<Item = (F, S)>, ) -> !
Unimplemented
Sourceimpl<F, S> BiVec<F, S>
impl<F, S> BiVec<F, S>
Sourcepub fn spare_capacity_mut(
&mut self,
) -> (&mut [MaybeUninit<F>], &mut [MaybeUninit<S>])
pub fn spare_capacity_mut( &mut self, ) -> (&mut [MaybeUninit<F>], &mut [MaybeUninit<S>])
Returns the remaining spare capacity of the vector as two slices of MaybeUninit<F> and MaybeUninit<S>.
The returned slices can be used to fill the BiVec with data (e.g. by reading from a file) before marking the data as initialized using the set_len method.
Sourcepub unsafe fn set_len(&mut self, new_len: usize)
pub unsafe fn set_len(&mut self, new_len: usize)
Forces the length of the BiVec to new_len.
This is a low-level operation that maintains none of the normal invariants of the type. Normally changing the length of a vector is done using other safe operations instead.
Safety
new_lenmust be less than or equal tocapacity().- The elements at old_len..new_len must be initialized.
Sourceimpl<F, S> BiVec<F, S>
impl<F, S> BiVec<F, S>
Sourcepub fn swap_remove(&mut self, first_index: usize, second_index: usize) -> (F, S)
pub fn swap_remove(&mut self, first_index: usize, second_index: usize) -> (F, S)
Removes the element at the given index, and returns it.
The removed element is replaced by the last element of the vector.
pub fn swap_remove_same(&mut self, index: usize) -> (F, S)
pub fn remove(&mut self, index: usize) -> (F, S)
pub fn retain_mut(&mut self, f: impl FnMut(&mut F, &mut S) -> bool)
pub fn retain(&mut self, f: impl FnMut(&F, &S) -> bool)
pub fn truncate(&mut self, new_len: usize)
Sourceimpl<F: Clone, S: Clone> BiVec<F, S>
impl<F: Clone, S: Clone> BiVec<F, S>
pub fn resize(&mut self, new_len: usize, value: (F, S))
pub fn resize_with(&mut self, new_len: usize, f: impl FnMut() -> (F, S))
pub fn extend_from_slice(&mut self, other: &[(F, S)])
pub fn extend_from_within(&mut self, src: impl RangeBounds<usize>)