BiVec

Struct BiVec 

pub struct BiVec<F, S> { /* private fields */ }

Implementations

Source

impl<F, S> BiVec<F, S>

pub fn into_vecs(self) -> (Vec<F>, Vec<S>)

Source

impl<F, S> BiVec<F, S>

pub fn new() -> Self

pub fn with_capacity(capacity: usize) -> Self

Source

impl<F, S> BiVec<F, S>

pub fn reserve(&mut self, additional: usize)

pub fn reserve_exact(&mut self, additional: usize)

Source

impl<F, S> BiVec<F, S>

pub fn append(&mut self, other: &mut BiVec<F, S>)

Appends the contents of other to self.

UNIMPLEMENTED
Source

impl<F, S> BiVec<F, S>

pub fn len(&self) -> usize

pub fn capacity(&self) -> usize

pub fn is_empty(&self) -> bool

Source

impl<F, S> BiVec<F, S>

pub fn split_at(&mut self, at: usize) -> !

Unimplement
pub fn split_off(&mut self, at: usize) -> !

Unimplement
Source

impl<F, S> BiVec<F, S>

pub fn dedup_first_elements(&mut self)

Unimplemented
pub fn dedup_second_elements(&mut self)

Unimplemented
Source

impl<F, S> BiVec<F, S>

pub fn splice( &mut self, range: impl RangeBounds<usize>, replace_with: impl IntoIterator<Item = (F, S)>, ) -> !

Unimplemented
Source

impl<F, S> BiVec<F, S>

pub fn drain(&mut self, range: impl RangeBounds<usize>) -> !

Unimplemented
Source

impl<F, S> BiVec<F, S>

pub fn clear(&mut self)

pub fn trim(&mut self)

Source

impl<F, S> BiVec<F, S>

pub fn leak(self) -> (&'static mut [F], &'static mut [S])

Source

impl<F, S> BiVec<F, S>

pub fn spare_capacity_mut( &mut self, ) -> (&mut [MaybeUninit<F>], &mut [MaybeUninit<S>])

Returns the remaining spare capacity of the vector as two slices of MaybeUninit<F> and MaybeUninit<S>.

The returned slices can be used to fill the BiVec with data (e.g. by reading from a file) before marking the data as initialized using the set_len method.

pub unsafe fn set_len(&mut self, new_len: usize)

Forces the length of the BiVec to new_len.

This is a low-level operation that maintains none of the normal invariants of the type. Normally changing the length of a vector is done using other safe operations instead.

Safety
  • new_len must be less than or equal to capacity().
  • The elements at old_len..new_len must be initialized.
Source

impl<F, S> BiVec<F, S>

pub fn swap_remove(&mut self, first_index: usize, second_index: usize) -> (F, S)

Removes the element at the given index, and returns it.

The removed element is replaced by the last element of the vector.

pub fn swap_remove_same(&mut self, index: usize) -> (F, S)

pub fn remove(&mut self, index: usize) -> (F, S)

pub fn retain_mut(&mut self, f: impl FnMut(&mut F, &mut S) -> bool)

pub fn retain(&mut self, f: impl FnMut(&F, &S) -> bool)

pub fn truncate(&mut self, new_len: usize)

Source

impl<F: Clone, S: Clone> BiVec<F, S>

pub fn resize(&mut self, new_len: usize, value: (F, S))

pub fn resize_with(&mut self, new_len: usize, f: impl FnMut() -> (F, S))

pub fn extend_from_slice(&mut self, other: &[(F, S)])

pub fn extend_from_within(&mut self, src: impl RangeBounds<usize>)

Source

impl<F, S> BiVec<F, S>

pub unsafe fn from_raw_parts( ptr1: *mut F, ptr2: *mut S, length: usize, capacity: usize, ) -> BiVec<F, S>

Source

impl<F, S> BiVec<F, S>

pub fn push(&mut self, f: F, s: S)

pub fn insert(&mut self, index: usize, f: F, s: S)

pub fn push_within_capacity(&mut self, f: F, s: S) -> Result<(), (F, S)>

Source

impl<F, S> BiVec<F, S>

pub fn as_slice(&self) -> (&[F], &[S])

pub fn as_slice_mut(&mut self) -> (&mut [F], &mut [S])

Source

impl<F, S> BiVec<F, S>

pub fn as_ptr(&self) -> (*const F, *const S)

pub fn as_mut_ptr(&mut self) -> (*mut F, *mut S)

Source

impl<F, S> BiVec<F, S>

pub fn into_boxed_slice(self) -> (Box<[F]>, Box<[S]>)